@@ -102,6 +102,7 @@ __all__ = (
     "DescribeImportImageTasksPaginatorName",
     "DescribeImportSnapshotTasksPaginatorName",
     "DescribeInstanceCreditSpecificationsPaginatorName",
+    "DescribeInstanceEventWindowsPaginatorName",
     "DescribeInstanceStatusPaginatorName",
     "DescribeInstanceTypeOfferingsPaginatorName",
     "DescribeInstanceTypesPaginatorName",
@@ -222,6 +223,7 @@ __all__ = (
     "ImageStateType",
     "ImageTypeValuesType",
     "InstanceAttributeNameType",
+    "InstanceEventWindowStateType",
     "InstanceExistsWaiterName",
     "InstanceHealthStatusType",
     "InstanceInterruptionBehaviorType",
@@ -376,6 +378,7 @@ __all__ = (
     "VpnProtocolType",
     "VpnStateType",
     "VpnStaticRouteSourceType",
+    "WeekDayType",
     "scopeType",
 )
 
@@ -523,6 +526,7 @@ DescribeImportSnapshotTasksPaginatorName = Literal["describe_import_snapshot_tas
 DescribeInstanceCreditSpecificationsPaginatorName = Literal[
     "describe_instance_credit_specifications"
 ]
+DescribeInstanceEventWindowsPaginatorName = Literal["describe_instance_event_windows"]
 DescribeInstanceStatusPaginatorName = Literal["describe_instance_status"]
 DescribeInstanceTypeOfferingsPaginatorName = Literal["describe_instance_type_offerings"]
 DescribeInstanceTypesPaginatorName = Literal["describe_instance_types"]
@@ -720,6 +724,7 @@ InstanceAttributeNameType = Literal[
     "sriovNetSupport",
     "userData",
 ]
+InstanceEventWindowStateType = Literal["active", "creating", "deleted", "deleting"]
 InstanceExistsWaiterName = Literal["instance_exists"]
 InstanceHealthStatusType = Literal["healthy", "unhealthy"]
 InstanceInterruptionBehaviorType = Literal["hibernate", "stop", "terminate"]
@@ -1259,6 +1264,7 @@ ResourceTypeType = Literal[
     "import-image-task",
     "import-snapshot-task",
     "instance",
+    "instance-event-window",
     "internet-gateway",
     "key-pair",
     "launch-template",
@@ -1439,4 +1445,5 @@ VpnEcmpSupportValueType = Literal["disable", "enable"]
 VpnProtocolType = Literal["openvpn"]
 VpnStateType = Literal["available", "deleted", "deleting", "pending"]
 VpnStaticRouteSourceType = Literal["Static"]
+WeekDayType = Literal["friday", "monday", "saturday", "sunday", "thursday", "tuesday", "wednesday"]
 scopeType = Literal["Availability Zone", "Region"]
